![](https://github.com/okawo80085/lose/workflows/unit%20tests/badge.svg)
# lose

wrapper for `PyTables`, has 3 classes rn:

`Loser` - base data handler, run `help()` for more info

`HumanIterator` - iterator, run `help()` for more info

`LOSE` - a mistake

```python
>>> import lose
(;^ω^)
>>> lose.Loser('test.h5')
<lose.dataHandler.Loser fname="test.h5", fast_active=False, verboseRepr=False at 0x7f36454ba820>
>>>
```

## installation
```
pip install lose
```

or

```
python setup.py install --user
```

or 

```
pip install git+https://github.com/okawo80085/lose
```

## docs

well there is none

run `help()` on objects if you want

## issues/contributions/what ever
just do it


[change log](changeLog.md)